#
# spec file for package thttpd
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define serverroot /srv/www
%if 0%{?suse_version} > 1220
%define with_systemd 1
%else
%define with_systemd 0
%endif
Name:           thttpd
Version:        2.29
Release:        6.0.2.1.sr20241202
Summary:        Small and simple webserver
License:        BSD-3-Clause
Group:          Productivity/Networking/Web/Servers
URL:            http://www.acme.com/software/thttpd/
Source:         http://www.acme.com/software/thttpd/%{name}-%{version}.tar.gz
Source1:        %{name}-initd.script
Source2:        %{name}.service
Source3:        %{name}.logrotate
Source4:        %{name}.conf
Patch0:         %{name}-2.25b-configure.patch
Patch1:         %{name}-2.25b-dirs.patch
Patch2:         %{name}-2.25b-time_h.patch
Patch3:         %{name}-2.25b-newautoconf.patch
Patch4:         %{name}-2.25b-sec.patch
Patch5:         %{name}-2.25b-static.patch
Patch6:         %{name}-2.25b-pie.patch
Patch7:         %{name}-2.25b-syslogtocern.diff
Patch8:         %{name}-2.25b-overflow.diff
Patch9:         %{name}-2.25b-chown.diff
Patch10:        %{name}-2.25b-zerolen.patch
# PATCH-FIX-SUSE CVE-2012-5640
Patch13:        thttpd-2.25b-CVE-2012-5640-check_crypt_return_value.patch
Patch14:        thttpd-CVE-2013-0348.patch
Patch15:        thttpd-crypt_is_in_crypt.h.patch
# PATCH-FIX-SUSE keep using deprecated function sigset
Patch16:        thttpd-c99.patch
BuildRequires:  automake
BuildRequires:  libtool
Requires(post): permissions
Requires:       group(www)
Recommends:     logrotate
# both packages provide /srw/www/htdocs/index.html
Conflicts:      apache2-example-pages
# both packages provide /usr/bin/htpasswd
Conflicts:      apache2-utils
Provides:       http_daemon
%if %{with_systemd}
BuildRequires:  pkgconfig(systemd)
%{?systemd_ordering}
%else
Requires(post): %fillup_prereq
Requires(post): %insserv_prereq
%endif

%description
Thttpd is a compact httpd serving daemon that can handle
high loads. While lacking many of the advanced features of Roxen
or Apache, thttpd operates without forking and is efficient
in memory use. Basic support for CGI scripts, authentication, and SSI
is provided. Advanced features include the ability to throttle
traffic.

%prep
%setup -q
%patch -P 0
%patch -P 1
%patch -P 2
%patch -P 3
%patch -P 4
%patch -P 5
%patch -P 6
%patch -P 7
%patch -P 8
%patch -P 9
%patch -P 10
%patch -P 13 -p1
%patch -P 14 -p1
%patch -P 15 -p1
%patch -P 16 -p1

%build
cp %{_datadir}/automake-1.*/config.* .
mv aclocal.m4 acinclude.m4
libtoolize --force
aclocal --force
autoconf -f
export V_CCOPT="%{optflags} -fPIC -DPIC -fPIE"
export CFLAGS="%{optflags} -fPIC -DPIC -fPIE"
export LDFLAGS="-pie -Wl,-z,relro,-z,now"
%configure
# parallel build causes problems, single thread build takes only 10s anyway
make -j1

%install
install -d %{buildroot}%{_bindir} \
    %{buildroot}%{_sbindir} \
    %{buildroot}%{_mandir}/man1 \
    %{buildroot}%{_mandir}/man8 \
    %{buildroot}%{serverroot}/htdocs/users
%make_install
install -D -m0644 index.html %{buildroot}/%{serverroot}/htdocs/index.html
install -D -m0644 %{SOURCE4} %{buildroot}%{_sysconfdir}/%{name}.conf
install -D -m0644 %{SOURCE3} %{buildroot}%{_sysconfdir}/logrotate.d/%{name}
%if %{with_systemd}
install -D -m0644 %{SOURCE2} %{buildroot}%{_unitdir}/%{name}.service
ln -s %{_sbindir}/service %{buildroot}%{_sbindir}/rc%{name}
%else
install -D -m0644 %{SOURCE1} %{buildroot}%{_initddir}/%{name}
ln -s %{buildroot}%{_initddir}/%{name} %{buildroot}%{_sbindir}/rc%{name}
%endif

%if %{with_systemd}
%pre
%service_add_pre %{name}.service
%endif

%post
%if %{with_systemd}
%service_add_post %{name}.service
%else
%{fillup_and_insserv thttpd}
%endif
%set_permissions %{_bindir}/makeweb

%verifyscript
%verify_permissions -e %{_bindir}/makeweb

%preun
%if %{with_systemd}
%service_del_preun %{name}.service
%else
%stop_on_removal thttpd
%endif

%postun
%if %{with_systemd}
%service_del_postun %{name}.service
%else
%restart_on_update thttpd
%insserv_cleanup
%endif

%files
%doc README config.h
%dir %{serverroot}
%dir %{serverroot}/htdocs
%{serverroot}/htdocs/*
%attr(775, root, www) %{serverroot}/htdocs/users
%verify(not mode) %attr(2751, root, www) %{_bindir}/makeweb
%{_bindir}/htpasswd
%{_sbindir}/*
%{_mandir}/*/*
%config %{_sysconfdir}/logrotate.d/%{name}
%if %{with_systemd}
%{_unitdir}/%{name}.service
%else
%config %{_initddir}/thttpd
%endif
%config(noreplace) %{_sysconfdir}/thttpd.conf

%changelog
* Tue Dec  3 2024 Giacomo Comes <gcomes.obs@gmail.com>
- added thttpd-c99.patch
  * keep using the deprecated function sigset
  * patch borrowed from fedora rpm
* Mon Feb 26 2024 pgajdos@suse.com
- Use %%patch -P N instead of deprecated %%patchN.
* Wed Nov 24 2021 Johannes Segitz <jsegitz@suse.com>
- Added hardening to systemd service(s) (bsc#1181400). Modified:
  * thttpd.service
* Thu May 14 2020 Vítězslav Čížek <vcizek@suse.com>
- Allow regular users to execute makeweb (bsc#1171580)
  * Set permissions to 2751
* Mon Feb  3 2020 Dominique Leuenberger <dimstar@opensuse.org>
- BuildRequire pkgconfig(systemd) instead of systemd: allow OBS to
  shortcut through the -mini flavors.
* Mon Oct 22 2018 Vítězslav Čížek <vcizek@suse.com>
- Update to 2.29 (bsc#1112629)
  Allow CGI to handle HTTP methods besides GET/HEAD/POST.
  Improvements to the FreeBSD startup script. (Craig Leres)
  Minor portability tweak in mmc.c.
  Fix to buffer overrun bug in htpasswd. Reported by Alessio Santoru as CVE-2017-17663.
- update thttpd-2.25b-overflow.diff
* Wed Oct 18 2017 jengelh@inai.de
- Trim filler wording from description.
* Mon Sep 11 2017 vcizek@suse.com
- Require group www (bsc#1057985)
* Mon Jun 26 2017 vcizek@suse.com
- update to 2.27
  Stats syslogs changed from LOG_INFO to LOG_NOTICE.
  Use memmove() for self-overlapping string copies instead of strcpy().
  Couple of subroutine name changes for consistency.
- drop thttpd-2.25b-strcpy.patch (upstream)
- enforce single process build, as parallel does fail sometimes
* Thu Sep 17 2015 vcizek@suse.com
- added Conflicts: apache2-example-pages
  * both packages provide /srv/www/htdocs/index.html
* Sun Jul  5 2015 vcizek@suse.com
- build with pie and full relro
* Thu Jun 18 2015 thehejik@suse.com
- package cleanup (bnc#899218)
  * removed SUSE branding
  * added logrotate support
  * changed note about default codepage
* Thu Jun  4 2015 vcizek@suse.com
- added Conflicts: apache2-utils
  * both packages provide /usr/bin/htpasswd
  * see comments in https://build.opensuse.org/request/show/310178
* Sun Nov 23 2014 bwiedemann@suse.com
- use /usr/sbin path in service to fix start (bnc#906696)
* Mon Sep 22 2014 vcizek@suse.com
- drop thttpd-2.25b.tar.bz2 (old tarball)
* Wed Sep  3 2014 vcizek@suse.com
- update to 2.26 (bnc#894285)
  Ignore ECONNABORTED on accept().
  Correctly implemented the config-file option change from "nosymlink"
  to "nosymlinkcheck", which was supposedly done in version 2.24.
  Removed mailto: link from default index page.
  Allow CGIs to provide both Location and Status headers.
  Better logic for figuring out CGI SERVER_NAME environment variable.
  Updated for clang, and general cleanup.
- dropped thttpd-2.25b-getline.patch (upstream)
- added thttpd-crypt_is_in_crypt.h.patch
* Fri Jul 18 2014 p.drouand@gmail.com
- Use systemd instead of sysvinit in openSUSE > 12.2
* Tue Dec  3 2013 vcizek@suse.com
- fix CVE-2013-0348 (bnc#853381)
  * don't create a world readable logfile
* Thu Jun 27 2013 crrodriguez@opensuse.org
- DO not add sample index.html that will conflict with apache
* Mon Mar  4 2013 vcizek@suse.com
- added checks for crypt() return value (CVE-2012-5640) (bnc#783165)
  * thttpd-2.25b-CVE-2012-5640-check_crypt_return_value.patch
* Wed Oct 24 2012 suse@ammler.ch
- use different versions of automake (SLE)
* Fri Jun  8 2012 vcizek@suse.com
- use %%set_permissions instead of %%run_permissions (bnc#764110)
* Tue May 29 2012 puzel@suse.com
- fix build with automake 1.12
* Thu Mar 22 2012 dvaleev@suse.com
- drop thttpd-2.25b-x86_64_machine_not_recognized.patch but copy
  config.guess from automake to fix ppc64 as well
* Tue Jan 31 2012 vcizek@suse.com
- fixed build and added -fpie for makeweb
* Wed Nov 23 2011 coolo@suse.com
- add libtool as buildrequire to avoid implicit dependency
* Sun Jun  7 2009 ro@suse.de
- rename getline to my_getline to avoid collision with function
  from glibc
* Tue May 26 2009 anicka@suse.cz
- add new branding (bnc#492693)
* Mon Jun 11 2007 pcerny@suse.cz
- fixed another syntax error in config file
* Fri Jun  8 2007 dmueller@suse.de
- fix syntax error in config file
* Wed Jun  6 2007 pcerny@suse.cz
- use %%config(noreplace) for /etc/thttpd.conf
* Tue Jun  5 2007 pcerny@suse.cz
- added Short-Description tag into init script
* Fri Jun  1 2007 pcerny@suse.cz
- added config file (/etc/thttpd.conf)
* Fri Feb 16 2007 mvaner@suse.cz
- Adding check for zero length
  - from Marcus Meissner
  - zerolen.patch
- Replacing strcpy with memmove when they overlap
  - strcpy.patch
- Both from #230776
* Wed Feb 14 2007 schwab@suse.de
- Fix building as non-root.
* Fri Mar 10 2006 anicka@suse.cz
- fix buffer overflows in htpasswd (#156978)
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Mon Nov 21 2005 anicka@suse.cz
- fix tmp race in syslogtocern (#131056)
* Wed Oct 12 2005 anicka@suse.cz
- use %%config(noreplace) for index.html
* Wed Jun 22 2005 anicka@suse.cz
- compile dynamic binaries instead of static
- compile htpasswd with -pie
* Wed Mar  9 2005 mcihar@suse.cz
- do not conflict with other webservers (bug #71742)
* Tue Feb 17 2004 tcrhak@suse.cz
- update to version 2.25b
* Tue Jan 13 2004 schwab@suse.de
- Fix use of aclocal.
* Wed Oct 29 2003 tcrhak@suse.cz
- update to 2.24, includes a fix for a buffer overflow [bug #32734]
- fixed virtual hosting security hole [bug #32757]
- fixed permissions according to permissions.secure,
  added macros %%run_permissions and %%verify_permissions
* Mon Sep  1 2003 tcrhak@suse.cz
- added macros %%stop_on_removal and %%restart_on_update [bug #29022]
* Thu Jun  5 2003 ro@suse.de
- remove unpackaged files from buildroot
* Tue Mar 11 2003 tcrhak@suse.cz
- fixed permissions of the init scipt [bug #25084]
* Tue Oct 15 2002 tcrhak@suse.cz
- substitute correct servroot during built
* Mon Oct 14 2002 tcrhak@suse.cz
- use /srv/www rather then /usr/local/httpd [bug #20802]
* Thu Aug  1 2002 ro@suse.de
- adapt server root
* Sat Jul 27 2002 kukuk@suse.de
- Change group from wwwadmin to www
* Sat Jul 27 2002 adrian@suse.de
- do not source rc.config anymore
* Tue Jul  2 2002 tcrhak@suse.cz
- update to version 2.23beta1
* Tue Jan 15 2002 tcrhak@suse.cz
- update to version 2.20c
- added thttpd-2.20c-sec.patch
- removed START_THTTPD from README.SuSE
* Mon Jan 14 2002 ro@suse.de
- removed START_THTTPD
* Fri Sep 21 2001 bjacke@suse.de
- fix version on template webpage
* Mon Sep  3 2001 adostal@suse.cz
- fix /etc/init.d in thttpd-SuSE.tar.bz2 files
- split patches on configure, dirs, time_h and newautoconf
* Thu Jun 14 2001 adostal@suse.cz
- fix for new autoconf
* Fri Apr 13 2001 nadvornik@suse.cz
- changed initscript according to skeleton
* Thu Mar  8 2001 nadvornik@suse.cz
- compiled with RPM_OPT_FLAGS
* Thu Feb 15 2001 nadvornik@suse.cz
- fixed to compile
* Wed Dec 13 2000 smid@suse.cz
- generatig of default page moved to %%install (it was in %%post and
- caused [#4566]
* Tue Dec 12 2000 smid@suse.cz
- default cgibin pattern changed [#4564]
- rcthttpd link added
* Sun Dec  3 2000 smid@suse.cz
- new version: 2.20b
* Fri Dec  1 2000 ro@suse.de
- moved init-script
* Thu Nov  2 2000 smid@suse.cz
- fix ugly bug in startup scripts
* Thu Sep 28 2000 smid@suse.cz
- new version: 2.20
* Wed Aug 30 2000 smid@suse.cz
- fix bug in startup script
* Wed Jul  5 2000 mha@suse.de
- new version: 2.19
* Tue May 23 2000 smid@suse.cz
- buildroot fixed
* Wed May  3 2000 smid@suse.cz
- buildroot added
* Tue Mar 21 2000 mha@suse.de
- update to 2.16
* Fri Mar  3 2000 uli@suse.de
- moved man pages to %%{_mandir}
* Mon Feb 28 2000 mha@suse.de
- new version: 2.15
* Thu Feb 17 2000 dipa@suse.de
- bug #1268 rc.config variable set to no
* Wed Jan 12 2000 mha@suse.de
- new version: 2.11
- new conflicts (roxen, apache, aolserv), provides (http_daemon)
- new homepage
* Tue Nov 16 1999 kukuk@suse.de
- Fix stack overflow
* Mon Sep 13 1999 bs@suse.de
- ran old prepare_spec on spec file to switch to new prepare_spec.
* Thu Sep  9 1999 bs@suse.de
- fixed call of Check at the end of %%install section
* Sun Jul 11 1999 mha@suse.de
- new package: thttpd (a _small_ webserver)
  absolutely no configuration needed - and yet save (chroot)!
